@@ -5,13 +5,12 @@ package client_test
 
 import (
 	"errors"
+	"os"
 	"testing"
 
 	"github.com/derailed/k9s/internal/client"
 	"github.com/rs/zerolog"
 	"github.com/stretchr/testify/assert"
-	v1 "k8s.io/api/core/v1"
-	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/cli-runtime/pkg/genericclioptions"
 )
 
@@ -58,11 +57,16 @@ func TestConfigCurrentCluster(t *testing.T) {
 		cluster string
 	}{
 		"default": {
-			flags:   &genericclioptions.ConfigFlags{KubeConfig: &kubeConfig},
-			cluster: "fred",
+			flags: &genericclioptions.ConfigFlags{
+				KubeConfig: &kubeConfig,
+			},
+			cluster: "zorg",
 		},
 		"custom": {
-			flags:   &genericclioptions.ConfigFlags{KubeConfig: &kubeConfig, ClusterName: &name},
+			flags: &genericclioptions.ConfigFlags{
+				KubeConfig: &kubeConfig,
+				Context:    &name,
+			},
 			cluster: "blee",
 		},
 	}
@@ -71,9 +75,9 @@ func TestConfigCurrentCluster(t *testing.T) {
 		u := uu[k]
 		t.Run(k, func(t *testing.T) {
 			cfg := client.NewConfig(u.flags)
-			ctx, err := cfg.CurrentClusterName()
+			ct, err := cfg.CurrentClusterName()
 			assert.Nil(t, err)
-			assert.Equal(t, u.cluster, ctx)
+			assert.Equal(t, u.cluster, ct)
 		})
 	}
 }
@@ -150,7 +154,7 @@ func TestConfigGetContext(t *testing.T) {
 		},
 		"custom": {
 			cluster: "bozo",
-			err:     errors.New("invalid context `bozo specified"),
+			err:     errors.New(`getcontext - invalid context specified: "bozo"`),
 		},
 	}
 
@@ -173,8 +177,8 @@ func TestConfigGetContext(t *testing.T) {
 func TestConfigSwitchContext(t *testing.T) {
 	cluster, kubeConfig := "duh", "./testdata/config"
 	flags := genericclioptions.ConfigFlags{
-		KubeConfig:  &kubeConfig,
-		ClusterName: &cluster,
+		KubeConfig: &kubeConfig,
+		Context:    &cluster,
 	}
 
 	cfg := client.NewConfig(&flags)
@@ -185,24 +189,11 @@ func TestConfigSwitchContext(t *testing.T) {
 	assert.Equal(t, "blee", ctx)
 }
 
-func TestConfigClusterNameFromContext(t *testing.T) {
-	cluster, kubeConfig := "duh", "./testdata/config"
-	flags := genericclioptions.ConfigFlags{
-		KubeConfig:  &kubeConfig,
-		ClusterName: &cluster,
-	}
-
-	cfg := client.NewConfig(&flags)
-	cl, err := cfg.ClusterNameFromContext("blee")
-	assert.Nil(t, err)
-	assert.Equal(t, "blee", cl)
-}
-
 func TestConfigAccess(t *testing.T) {
-	cluster, kubeConfig := "duh", "./testdata/config"
+	context, kubeConfig := "duh", "./testdata/config"
 	flags := genericclioptions.ConfigFlags{
-		KubeConfig:  &kubeConfig,
-		ClusterName: &cluster,
+		KubeConfig: &kubeConfig,
+		Context:    &context,
 	}
 
 	cfg := client.NewConfig(&flags)
@@ -211,11 +202,24 @@ func TestConfigAccess(t *testing.T) {
 	assert.True(t, len(acc.GetDefaultFilename()) > 0)
 }
 
-func TestConfigContexts(t *testing.T) {
+func TestConfigContextNames(t *testing.T) {
 	cluster, kubeConfig := "duh", "./testdata/config"
 	flags := genericclioptions.ConfigFlags{
-		KubeConfig:  &kubeConfig,
-		ClusterName: &cluster,
+		KubeConfig: &kubeConfig,
+		Context:    &cluster,
+	}
+
+	cfg := client.NewConfig(&flags)
+	cc, err := cfg.ContextNames()
+	assert.Nil(t, err)
+	assert.Equal(t, 3, len(cc))
+}
+
+func TestConfigContexts(t *testing.T) {
+	context, kubeConfig := "duh", "./testdata/config"
+	flags := genericclioptions.ConfigFlags{
+		KubeConfig: &kubeConfig,
+		Context:    &context,
 	}
 
 	cfg := client.NewConfig(&flags)
@@ -224,46 +228,24 @@ func TestConfigContexts(t *testing.T) {
 	assert.Equal(t, 3, len(cc))
 }
 
-func TestConfigContextNames(t *testing.T) {
-	cluster, kubeConfig := "duh", "./testdata/config"
-	flags := genericclioptions.ConfigFlags{
-		KubeConfig:  &kubeConfig,
-		ClusterName: &cluster,
-	}
-
-	cfg := client.NewConfig(&flags)
-	cc, err := cfg.ContextNames()
-	assert.Nil(t, err)
-	assert.Equal(t, 3, len(cc))
-}
-
-func TestConfigClusterNames(t *testing.T) {
-	cluster, kubeConfig := "duh", "./testdata/config"
-	flags := genericclioptions.ConfigFlags{
-		KubeConfig:  &kubeConfig,
-		ClusterName: &cluster,
-	}
-
-	cfg := client.NewConfig(&flags)
-	cc, err := cfg.ClusterNames()
-	assert.Nil(t, err)
-	assert.Equal(t, 3, len(cc))
-}
-
 func TestConfigDelContext(t *testing.T) {
-	cluster, kubeConfig := "duh", "./testdata/config.1"
+	assert.NoError(t, cp("./testdata/config.2", "./testdata/config.1"))
+
+	context, kubeConfig := "duh", "./testdata/config.1"
 	flags := genericclioptions.ConfigFlags{
-		KubeConfig:  &kubeConfig,
-		ClusterName: &cluster,
+		KubeConfig: &kubeConfig,
+		Context:    &context,
 	}
 
 	cfg := client.NewConfig(&flags)
 	err := cfg.DelContext("fred")
-	assert.Nil(t, err)
+	assert.NoError(t, err)
+
 	cc, err := cfg.ContextNames()
-	assert.Nil(t, err)
+	assert.NoError(t, err)
 	assert.Equal(t, 1, len(cc))
-	assert.Equal(t, "blee", cc[0])
+	_, ok := cc["blee"]
+	assert.True(t, ok)
 }
 
 func TestConfigRestConfig(t *testing.T) {
@@ -275,7 +257,7 @@ func TestConfigRestConfig(t *testing.T) {
 	cfg := client.NewConfig(&flags)
 	rc, err := cfg.RESTConfig()
 	assert.Nil(t, err)
-	assert.Equal(t, "https://localhost:3000", rc.Host)
+	assert.Equal(t, "https://localhost:3002", rc.Host)
 }
 
 func TestConfigBadConfig(t *testing.T) {
@@ -289,13 +271,13 @@ func TestConfigBadConfig(t *testing.T) {
 	assert.NotNil(t, err)
 }
 
-func TestNamespaceNames(t *testing.T) {
-	nn := []v1.Namespace{
-		{ObjectMeta: metav1.ObjectMeta{Name: "ns1"}},
-		{ObjectMeta: metav1.ObjectMeta{Name: "ns2"}},
+// Helpers...
+
+func cp(src string, dst string) error {
+	data, err := os.ReadFile(src)
+	if err != nil {
+		return err
 	}
 
-	nns := client.NamespaceNames(nn)
-	assert.Equal(t, 2, len(nns))
-	assert.Equal(t, []string{"ns1", "ns2"}, nns)
+	return os.WriteFile(dst, data, 0600)
 }
