@@ -47,7 +47,6 @@ func (c *Context) Validate(conn client.Connection, ks KubeSettings) {
 	if c.PortForwardAddress == "" {
 		c.PortForwardAddress = DefaultPFAddress
 	}
-
 	if cl, err := ks.CurrentClusterName(); err != nil {
 		c.ClusterName = cl
 	}
@@ -55,9 +54,6 @@ func (c *Context) Validate(conn client.Connection, ks KubeSettings) {
 	if c.Namespace == nil {
 		c.Namespace = NewNamespace()
 	}
-	if c.Namespace.Active == client.BlankNamespace {
-		c.Namespace.Active = client.DefaultNamespace
-	}
 	c.Namespace.Validate(conn, ks)
 
 	if c.View == nil {
