@@ -4,6 +4,7 @@
 package render
 
 import (
+	"math"
 	"sort"
 	"strconv"
 	"strings"
@@ -22,8 +23,8 @@ import (
 	"k8s.io/apimachinery/pkg/util/duration"
 )
 
-func computeVulScore(spec *v1.PodSpec) string {
-	if vul.ImgScanner == nil {
+func computeVulScore(m metav1.ObjectMeta, spec *v1.PodSpec) string {
+	if vul.ImgScanner == nil || vul.ImgScanner.ShouldExcludes(m) {
 		return "0"
 	}
 	ii := ExtractImages(spec)
@@ -48,6 +49,9 @@ func durationToSeconds(duration string) int64 {
 	if len(duration) == 0 {
 		return 0
 	}
+	if duration == NAValue {
+		return math.MaxInt64
+	}
 
 	num := make([]rune, 0, 5)
 	var n, m int64
