@@ -16,5 +16,5 @@ func TestReplicaSetRender(t *testing.T) {
 
 	assert.NoError(t, c.Render(load(t, "rs"), "", &r))
 	assert.Equal(t, "icx/icx-db-7d4b578979", r.ID)
-	assert.Equal(t, render.Fields{"icx", "icx-db-7d4b578979", "1", "1", "1"}, r.Fields[:5])
+	assert.Equal(t, render.Fields{"icx", "icx-db-7d4b578979", "0", "1", "1", "1"}, r.Fields[:6])
 }
