@@ -15,7 +15,8 @@ type SelectTable struct {
 	model      Tabular
 	selectedFn func(string) string
 	marks      map[string]struct{}
-	fgColor    tcell.Color
+	selFgColor tcell.Color
+	selBgColor tcell.Color
 }
 
 // SetModel sets the table model.
@@ -102,7 +103,7 @@ func (s *SelectTable) GetSelectedRowIndex() int {
 }
 
 // SelectRow select a given row by index.
-func (s *SelectTable) SelectRow(r int, broadcast bool) {
+func (s *SelectTable) SelectRow(r, c int, broadcast bool) {
 	if !broadcast {
 		s.SetSelectionChangedFunc(nil)
 	}
@@ -110,13 +111,13 @@ func (s *SelectTable) SelectRow(r int, broadcast bool) {
 		r = c + 1
 	}
 	defer s.SetSelectionChangedFunc(s.selectionChanged)
-	s.Select(r, 0)
+	s.Select(r, c)
 }
 
 // UpdateSelection refresh selected row.
 func (s *SelectTable) updateSelection(broadcast bool) {
-	r, _ := s.GetSelection()
-	s.SelectRow(r, broadcast)
+	r, c := s.GetSelection()
+	s.SelectRow(r, c, broadcast)
 }
 
 func (s *SelectTable) selectionChanged(r, c int) {
@@ -124,7 +125,9 @@ func (s *SelectTable) selectionChanged(r, c int) {
 		return
 	}
 	if cell := s.GetCell(r, c); cell != nil {
-		s.SetSelectedStyle(tcell.StyleDefault.Foreground(s.fgColor).Background(cell.Color).Attributes(tcell.AttrBold))
+		s.SetSelectedStyle(
+			tcell.StyleDefault.Foreground(s.selFgColor).
+				Background(cell.Color).Attributes(tcell.AttrBold))
 	}
 }
 
