@@ -9,7 +9,6 @@ import (
 
 	"github.com/derailed/k9s/internal/config"
 	"github.com/derailed/tview"
-	"github.com/rs/zerolog/log"
 )
 
 const spacer = "     "
@@ -155,7 +154,5 @@ func (l *LogIndicator) Refresh() {
 		l.indicator = append(l.indicator, fmt.Sprintf(toggleOffFmt, "Wrap", "")...)
 	}
 
-	log.Debug().Msgf("INDICATOR: %q", l.indicator)
-
 	_, _ = l.Write(l.indicator)
 }
