@@ -5,6 +5,7 @@ package view
 
 import (
 	"github.com/derailed/k9s/internal/client"
+	"github.com/derailed/k9s/internal/dao"
 	"github.com/derailed/k9s/internal/ui"
 	"github.com/derailed/tcell/v2"
 	v1 "k8s.io/api/core/v1"
@@ -37,7 +38,7 @@ func (s *Secret) bindKeys(aa ui.KeyActions) {
 }
 
 func (s *Secret) refCmd(evt *tcell.EventKey) *tcell.EventKey {
-	return scanRefs(evt, s.App(), s.GetTable(), "v1/secrets")
+	return scanRefs(evt, s.App(), s.GetTable(), dao.SecGVR)
 }
 
 func (s *Secret) decodeCmd(evt *tcell.EventKey) *tcell.EventKey {
